==> images-201.8743.12-sources.jar: org/intellij/images/fileTypes/impl/SvgFileType.java <==
/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.intellij.images.fileTypes.impl;

import com.intellij.ide.IdeBundle;
import com.intellij.ide.highlighter.XmlLikeFileType;
import com.intellij.openapi.fileTypes.UIBasedFileType;
import icons.ImagesIcons;
import org.jetbrains.annotations.NotNull;

import javax.swing.*;

/**
 * @author Konstantin Bulenkov
 */
public final class SvgFileType extends XmlLikeFileType implements UIBasedFileType {
  public static final SvgFileType INSTANCE = new SvgFileType();

  private SvgFileType() {
    super(SvgLanguage.INSTANCE);
  }

  @NotNull
  @Override
  public String getName() {
    return "SVG";
  }

  @NotNull
  @Override
  public String getDescription() {
    return IdeBundle.message("filetype.description.scalable.vector.graphics");
  }

  @NotNull
  @Override
  public String getDefaultExtension() {
    return "svg";
  }

  @NotNull
  @Override
  public Icon getIcon() {
    return ImagesIcons.ImagesFileType;
  }
}

==> images-212.5080.64-sources.jar: org/intellij/images/fileTypes/impl/SvgFileType.java <==
/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.intellij.images.fileTypes.impl;

import com.intellij.ide.IdeBundle;
import com.intellij.ide.highlighter.XmlLikeFileType;
import com.intellij.openapi.fileTypes.UIBasedFileType;
import icons.ImagesIcons;
import org.jetbrains.annotations.NotNull;

import javax.swing.*;

/**
 * @author Konstantin Bulenkov
 */
public final class SvgFileType extends XmlLikeFileType implements UIBasedFileType {
  public static final SvgFileType INSTANCE = new SvgFileType();

  private SvgFileType() {
    super(SvgLanguage.INSTANCE);
  }

  @NotNull
  @Override
  public String getName() {
    return "SVG";
  }

  @NotNull
  @Override
  public String getDescription() {
    return IdeBundle.message("filetype.scalable.vector.graphics.description");
  }

  @NotNull
  @Override
  public String getDefaultExtension() {
    return "svg";
  }

  @NotNull
  @Override
  public Icon getIcon() {
    return ImagesIcons.ImagesFileType;
  }
}
